=======
History
=======

0.0.1 (2019-07-29)
------------------

* First release on PyPI.
* Create workplace
* Rename files
* Added a config file
* Updated tox config files
* Updated travis config files
* Empty unit tests
